#!/bin/sh
# Install postgresql-9.1
#
#
# Some checkings before installing

trap "on_error; on_exit; exit" INT QUIT TERM

source /usr/local/bin/functions.sh
source ./application_checks.sh
source ./packages_template.sh
source ./user.sh
source ./web.sh
source ./postgresql.sh

app="innovaphone-exchange"

installed_packages=""
cfg_tmp_dir=""
config_pg_dir=""
config_pg_file=""
innovaphone_user=""
innovaphone_group=""
database_user=""
database_name=""
cron_table=""

function on_exit() {
    if [ -n "$cfg_tmp_dir" ]; then
        rm -rf $cfg_tmp_dir
    fi
    apt-get clean
} 

function on_error() {
    # cron
    if [ -n "$cron_table" ]; then
	    if [ -f "$cron_table" ]; then
            rm $cron_table
	    fi
    fi
    # drop database
    if [ -n "$database_name" ]; then
        sudo -u postgres dropdb $database_name
    fi
    # drop database user
    if [ -n "$database_user" ]; then
        sudo -u postgres psql -c "DROP USER \"${database_user}\"" postgres 2>/dev/null
    fi
    # uninstall packages
    if [ -n "$installed_packages" ]; then
        apt-get -y --force-yes purge $installed_packages 
	    apt-get autoremove
    fi
    # linux-user
    if [ -n "$innovaphone_user" ]; then
        deluser $innovaphone_user 2>/dev/null
    fi
    if [ -n "$innovaphone_group" ]; then
        delgroup $innovaphone_group 2>/dev/null
    fi
    if [ -d /home/${app} ]; then
        rm -rf /home/${app}
    fi
    if [ -n "$cfg_tmp_dir" -a -n "$config_pg_dir" ]; then
        cp $cfg_tmp_dir/postgresql.conf $config_pg_dir 2>/dev/null
        cp $cfg_tmp_dir/pg_hba.conf $config_pg_dir 2>/dev/null
    fi
    on_exit
}

# check application, hotfix, version etc.
check_application ${app}

if [ ! -d /tmp ]; then
    log_msg "Directory tmp does not exists, create"
    mkdir /tmp
    chmod 777 /tmp
    chmod a+t /tmp    
fi

# Keep the config files that will be modified in case something goes wrong...
cfg_tmp_dir=`mktemp -d /tmp/config.$$.XXXX`
if [ $? -ne 0 ]; then
    log_error "Can't create temp config file, exiting..."
    on_error
    exit 1
fi
chmod 777 $cfg_tmp_dir

install_packages install "php5-mcrypt"
if [ $? -ne 0 ]; then
    exit 1
fi

# call create_user function of user.sh
create_user ${app}

# call postgresql function of postgresql.sh
postgresql ${app} $cfg_tmp_dir exchange_database.psql exchange

log_msg "Install exchange calendar connector files"

install_web ${app} "web/${app}"

exchange_conf=/home/${app}/exchange.conf
touch $exchange_conf
echo '<?xml version="1.0" encoding="utf-8"?>' > $exchange_conf
echo '<config>' >> $exchange_conf
echo '</config>' >> $exchange_conf
chmod 770 $exchange_conf
chown ${app}:${app} $exchange_conf

uninstall=/home/${app}/uninstall.sh
mv uninstall.sh $uninstall
chmod 755 $uninstall
chown www-data:www-data $uninstall

# Install exchange cron job
cron_table="/etc/cron.d/innovaphone_exchange"
exchange_script="/var/www/innovaphone/apps/${app}/exchange.php"
exchange_log="/var/www/innovaphone/apps/${app}/log/${app}.log"
if grep $exchange_script < $cron_table 1>/dev/null
then
    echo "$(date '+%Y-%m-%d %H:%M:%S') - exchange script already in crontab"
else
    echo "$(date '+%Y-%m-%d %H:%M:%S') - inserting exchange script to crontab"
    echo "PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin" >> ${cron_table}
    echo "* * * * * root [ -x /usr/bin/php5 ] && nice -1 /usr/bin/php5 -q ${exchange_script} >> ${exchange_log} 2>&1" >> ${cron_table}
fi
/etc/init.d/cron restart

# restart rsyslog to (re)create the log files
/etc/init.d/rsyslog restart
# do not change "Installation was successful", it will be matched!
log_msg "You may now configure the CDR interface at your PBX"
log_msg "The web server will be restarted a few seconds after the installation!"
log_msg "Installation was successful"
sleep 10s
php5-cgi /var/www/innovaphone/update_webserver_cfg.php

on_exit
exit 0
